"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CommonErrorNormalizer = (function () {
    function CommonErrorNormalizer() {
        this.name = 'error-event';
    }
    CommonErrorNormalizer.prototype.typeCheck = function (possibleErrorEvent) {
        if (possibleErrorEvent instanceof ErrorEvent) {
            return true;
        }
        return false;
    };
    CommonErrorNormalizer.prototype.normalize = function (errorEvent) {
        var id = '';
        var content = '';
        var title = '';
        var error = null;
        var labels = [];
        if (errorEvent.error && errorEvent.error.rejection) {
            id = 'runtime-in-promise';
            title = 'Promise broken';
            content = 'The error was caught in an unhandled promise.\n';
            error = errorEvent.error.rejection;
        }
        else if (errorEvent.error) {
            id = 'runtime-thown-error';
            title = 'Error thrown';
            content = 'The error was thrown in the application body.\n';
            error = errorEvent.error;
        }
        else {
            id = 'script-error';
            title = 'Script error';
            content = errorEvent.message;
        }
        if (error) {
            content += "Error Type: " + error.name + ".";
            labels.push(id + "-" + error.name);
            id += error.message;
            title += error.message;
            content += "\n      \n        Message: " + error.message + ".\n        Stack: " + error.stack + ".";
        }
        else {
            labels.push(id + "-" + errorEvent.message);
        }
        return {
            id: id, title: title, content: content, labels: labels
        };
    };
    return CommonErrorNormalizer;
}());
exports.CommonErrorNormalizer = CommonErrorNormalizer;

//# sourceMappingURL=common-error.normalizer.js.map
