"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var respawn_camping_service_1 = require("../respawn-camping/respawn-camping.service");
var ErrorHandlingService = (function () {
    function ErrorHandlingService() {
        this.camper = new respawn_camping_service_1.RespawnCampingService();
        this.errorNormalizer = {};
        if (!ErrorHandlingService.instance) {
            ErrorHandlingService.instance = this;
        }
        return ErrorHandlingService.instance;
    }
    ErrorHandlingService.prototype.declareCustomErrorNormalizer = function (clazzes) {
        var _this = this;
        clazzes.forEach(function (clazz) {
            var normalizer = new clazz();
            _this.errorNormalizer[normalizer.name] = normalizer;
        });
    };
    ErrorHandlingService.prototype.identifyNormalizer = function (thrown) {
        var _this = this;
        var nameFound = Object.keys(this.errorNormalizer).find(function (name) { return _this.errorNormalizer[name].typeCheck(thrown); }) || null;
        return this.errorNormalizer[nameFound || ''] || null;
    };
    ErrorHandlingService.prototype.launch = function (thrownThing) {
        var normalizer = this.identifyNormalizer(thrownThing);
        if (normalizer) {
            var normalized = normalizer.normalize(thrownThing);
            if (normalized) {
                this.camper.registerRespawnedBug(normalizer.name, normalized);
            }
        }
    };
    return ErrorHandlingService;
}());
ErrorHandlingService.instance = null;
exports.ErrorHandlingService = ErrorHandlingService;

//# sourceMappingURL=error-handler.service.js.map
