"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var object_util_1 = require("../util/object.util");
var HttpService = (function () {
    function HttpService() {
        this.objectUtil = new object_util_1.ObjectUtil();
        this.defaultHeaders = {
            'Content-Type': 'application/json'
        };
        if (!HttpService.instance) {
            HttpService.instance = this;
        }
        return HttpService.instance;
    }
    HttpService.prototype.request = function (options) {
        var xhr = new HttpService.XMLHttpRequest();
        xhr.open(options.method, options.server);
        this.setRequestHeaders(xhr, options.headers || {});
        var promise = this.listenRequest(xhr);
        if (options.payload) {
            xhr.send(JSON.stringify(options.payload));
        }
        else {
            xhr.send();
        }
        return promise;
    };
    HttpService.prototype.listenRequest = function (xhr) {
        var statusCodeSimplification = 100;
        var statusCodeSuccessLevel = 2;
        var httpReadyStateDone = 4;
        var httpNoContentStatus = 204;
        return new Promise(function (resolve, reject) {
            xhr.onreadystatechange = function () {
                if (xhr.readyState === httpReadyStateDone) {
                    if (Math.floor(xhr.status / statusCodeSimplification) === statusCodeSuccessLevel) {
                        try {
                            var responseData = xhr.status === httpNoContentStatus ? null : JSON.parse(xhr.responseText);
                            resolve(responseData);
                        }
                        catch (e) {
                            reject(e);
                        }
                    }
                    else {
                        reject(xhr);
                    }
                }
            };
        });
    };
    HttpService.prototype.setRequestHeaders = function (xhr, headers) {
        var newHeaders = this.objectUtil.assign(this.defaultHeaders, headers);
        Object.keys(newHeaders).forEach(function (key) {
            xhr.setRequestHeader(key, String(newHeaders[key]));
        });
    };
    return HttpService;
}());
HttpService.instance = null;
HttpService.XMLHttpRequest = XMLHttpRequest;
exports.HttpService = HttpService;

//# sourceMappingURL=http.service.js.map
