"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_method_const_1 = require("../http/http-method.const");
var environment_service_1 = require("./../environment.service");
var http_service_1 = require("./../http/http.service");
var JiraIntegrationApi = (function () {
    function JiraIntegrationApi() {
        this.http = new http_service_1.HttpService();
        this.environment = new environment_service_1.EnvironmentService();
        if (!JiraIntegrationApi.instance) {
            JiraIntegrationApi.instance = this;
        }
        return JiraIntegrationApi.instance;
    }
    JiraIntegrationApi.prototype.createIssue = function (createIssue) {
        return this.http.request({
            method: http_method_const_1.HttpMethod.POST,
            server: this.mountPath('issue') + "?updateHistory=" + String(this.environment.updateJiraHistory),
            headers: this.generateAuthHeader(),
            payload: createIssue
        });
    };
    JiraIntegrationApi.prototype.findIssueByLabel = function (labels, maxResults) {
        var labelsCondition = labels.map(function (label) { return 'labels = ' + label; }).join(' AND ');
        var configuredMaxResults = maxResults ? "&maxResults=" + maxResults : '';
        var jql = "project = " + this.environment.defaultProjectKey + " AND issuetype = " + this.environment.bugTypeName + " AND " + labelsCondition;
        var queryString = "?currentProjectId=" + this.environment.defaultProjectKey + "&jql=" + jql + "&fields=summary,issuetype" + configuredMaxResults;
        return this.http.request({
            method: http_method_const_1.HttpMethod.GET,
            server: this.mountPath("search" + queryString),
            headers: this.generateAuthHeader()
        });
    };
    JiraIntegrationApi.prototype.commentOnIssue = function (issueKey, comment) {
        return this.http.request({
            method: http_method_const_1.HttpMethod.POST,
            server: this.mountPath("issue/" + issueKey + "/comment"),
            headers: this.generateAuthHeader(),
            payload: comment
        });
    };
    JiraIntegrationApi.prototype.getIssue = function (issueKey) {
        return this.http.request({
            method: http_method_const_1.HttpMethod.GET,
            server: this.mountPath("issue/" + issueKey + "?fields=comment"),
            headers: this.generateAuthHeader()
        });
    };
    JiraIntegrationApi.prototype.getIssueTransitionHistory = function (issueKey) {
        return this.http.request({
            method: http_method_const_1.HttpMethod.GET,
            server: this.mountPath("issue/" + issueKey + "/transitions"),
            headers: this.generateAuthHeader()
        });
    };
    JiraIntegrationApi.prototype.setIssueTransaction = function (issueKey, transactId) {
        return this.http.request({
            method: http_method_const_1.HttpMethod.POST,
            server: this.mountPath("issue/" + issueKey + "/transitions"),
            headers: this.generateAuthHeader(),
            payload: {
                transition: { id: transactId }
            }
        });
    };
    JiraIntegrationApi.prototype.mountPath = function (endpoint) {
        return this.environment.atlassianJiraServer + "rest/api/" + this.environment.jiraVersion + "/" + endpoint;
    };
    JiraIntegrationApi.prototype.generateAuthHeader = function () {
        var headers = {};
        if (this.environment.basicAuth) {
            headers['Authorization'] = "Basic " + this.environment.basicAuth;
        }
        return headers;
    };
    return JiraIntegrationApi;
}());
JiraIntegrationApi.instance = null;
exports.JiraIntegrationApi = JiraIntegrationApi;

//# sourceMappingURL=jira-integration.api.js.map
