"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var environment_service_1 = require("../environment.service");
var error_handler_service_1 = require("../error-handler/error-handler.service");
var HandlerBuilder = (function () {
    function HandlerBuilder() {
        this.enviroment = new environment_service_1.EnvironmentService();
        this.errorHandling = new error_handler_service_1.ErrorHandlingService();
        if (!HandlerBuilder.instance) {
            HandlerBuilder.instance = this;
        }
        return HandlerBuilder.instance;
    }
    HandlerBuilder.prototype.declareCustomErrorNormalizer = function (clazzes) {
        this.errorHandling.declareCustomErrorNormalizer(clazzes);
        return this;
    };
    HandlerBuilder.prototype.setAtlassianJiraServer = function (server) {
        this.enviroment.atlassianJiraServer = server;
        return this;
    };
    HandlerBuilder.prototype.setDefaultProjectKey = function (projectKey) {
        this.enviroment.defaultProjectKey = projectKey;
        return this;
    };
    HandlerBuilder.prototype.setBugTypeName = function (bugTypeName) {
        this.enviroment.bugTypeName = bugTypeName;
        return this;
    };
    HandlerBuilder.prototype.setInitialTransactionId = function (initialTransactionId) {
        this.enviroment.initialTransactionId = initialTransactionId;
        return this;
    };
    HandlerBuilder.prototype.setMaximumAmountOfIssues = function (maxAmount) {
        this.enviroment.stopInteractWhen.maximumAmountOfIssuesReached = maxAmount;
        return this;
    };
    HandlerBuilder.prototype.basicAuth = function (basicAuth) {
        this.enviroment.basicAuth = basicAuth;
        return this;
    };
    HandlerBuilder.prototype.updateJiraHistoryOnIssueCreate = function () {
        this.enviroment.updateJiraHistory = true;
        return this;
    };
    HandlerBuilder.prototype.build = function () {
        return new error_handler_service_1.ErrorHandlingService();
    };
    return HandlerBuilder;
}());
HandlerBuilder.instance = null;
exports.HandlerBuilder = HandlerBuilder;

//# sourceMappingURL=handler.builder.js.map
